==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased.md <==
# AmazonCloudWatchEventEventBased


```text
aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased
```

```text
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased')
```



| Illustration | AmazonCloudWatchEventEventBased | AmazonCloudWatchEventEventBasedCard | AmazonCloudWatchEventEventBasedGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased.png) | ![illustration for AmazonCloudWatchEventEventBased](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased.Local.png) | ![illustration for AmazonCloudWatchEventEventBasedCard](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBasedCard.Local.png) | ![illustration for AmazonCloudWatchEventEventBasedGroup](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBasedGroup.Local.png) |




## AmazonCloudWatchEventEventBased

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventEventBased
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased')

' renders the element
AmazonCloudWatchEventEventBased('AmazonCloudWatchEventEventBased', 'Amazon Cloud Watch Event Event Based', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventEventBased
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased')

' renders the element
AmazonCloudWatchEventEventBased('AmazonCloudWatchEventEventBased', 'Amazon Cloud Watch Event Event Based', 'an optional tech label')
@enduml
```

## AmazonCloudWatchEventEventBasedCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventEventBasedCard
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased')

' renders the element
AmazonCloudWatchEventEventBasedCard('AmazonCloudWatchEventEventBasedCard', 'Amazon Cloud Watch Event Event Based Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventEventBasedCard
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased')

' renders the element
AmazonCloudWatchEventEventBasedCard('AmazonCloudWatchEventEventBasedCard', 'Amazon Cloud Watch Event Event Based Card', 'an optional description')
@enduml
```

## AmazonCloudWatchEventEventBasedGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventEventBasedGroup
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased')

' renders the element
AmazonCloudWatchEventEventBasedGroup('AmazonCloudWatchEventEventBasedGroup', 'Amazon Cloud Watch Event Event Based Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventEventBasedGroup
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased')

' renders the element
AmazonCloudWatchEventEventBasedGroup('AmazonCloudWatchEventEventBasedGroup', 'Amazon Cloud Watch Event Event Based Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased.md <==
# AmazonCloudWatchEventEventBased


```text
aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased
```

```text
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased')
```



| Illustration | AmazonCloudWatchEventEventBased | AmazonCloudWatchEventEventBasedCard | AmazonCloudWatchEventEventBasedGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased.png) | ![illustration for AmazonCloudWatchEventEventBased](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased.Local.png) | ![illustration for AmazonCloudWatchEventEventBasedCard](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBasedCard.Local.png) | ![illustration for AmazonCloudWatchEventEventBasedGroup](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBasedGroup.Local.png) |




## AmazonCloudWatchEventEventBased

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventEventBased
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased')

' renders the element
AmazonCloudWatchEventEventBased('AmazonCloudWatchEventEventBased', 'Amazon Cloud Watch Event Event Based', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventEventBased
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased')

' renders the element
AmazonCloudWatchEventEventBased('AmazonCloudWatchEventEventBased', 'Amazon Cloud Watch Event Event Based', 'an optional tech label')
@enduml
```

## AmazonCloudWatchEventEventBasedCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventEventBasedCard
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased')

' renders the element
AmazonCloudWatchEventEventBasedCard('AmazonCloudWatchEventEventBasedCard', 'Amazon Cloud Watch Event Event Based Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventEventBasedCard
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased')

' renders the element
AmazonCloudWatchEventEventBasedCard('AmazonCloudWatchEventEventBasedCard', 'Amazon Cloud Watch Event Event Based Card', 'an optional description')
@enduml
```

## AmazonCloudWatchEventEventBasedGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventEventBasedGroup
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased')

' renders the element
AmazonCloudWatchEventEventBasedGroup('AmazonCloudWatchEventEventBasedGroup', 'Amazon Cloud Watch Event Event Based Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventEventBasedGroup
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchEventEventBased')

' renders the element
AmazonCloudWatchEventEventBasedGroup('AmazonCloudWatchEventEventBasedGroup', 'Amazon Cloud Watch Event Event Based Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
